FUI constructor

const FUI(
  1. String file, {
  2. Key? key,
  3. double? width,
  4. double? height,
  5. Color? color,
  6. String? semanticLabel,
  7. BoxFit fit = BoxFit.contain,
  8. bool matchTextDirection = false,
})

Creates a fui_kit icon.

file is the SVG asset path of the icon, normally one of the constants exposed by the style classes (for example RegularRounded.add).

Implementation

const FUI(
  this.file, {
  super.key,
  this.width,
  this.height,
  this.color,
  this.semanticLabel,
  this.fit = BoxFit.contain,
  this.matchTextDirection = false,
});